==> swfdec-0.5.2.tar.gz: swfdec-0.5.2/libswfdec/swfdec_marshal.h <==

#ifndef __swfdec_marshal_MARSHAL_H__
#define __swfdec_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:DOUBLE,DOUBLE,INT (./swfdec_marshal.list:1) */
extern void swfdec_marshal_BOOLEAN__DOUBLE_DOUBLE_INT (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);

/* BOOLEAN:UINT,UINT,BOOLEAN (./swfdec_marshal.list:2) */
extern void swfdec_marshal_BOOLEAN__UINT_UINT_BOOLEAN (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);

/* VOID:DOUBLE,DOUBLE,DOUBLE,DOUBLE (./swfdec_marshal.list:3) */
extern void swfdec_marshal_VOID__DOUBLE_DOUBLE_DOUBLE_DOUBLE (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
                                                              const GValue *param_values,
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);

/* VOID:STRING,STRING (./swfdec_marshal.list:4) */
extern void swfdec_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* VOID:UINT,UINT (./swfdec_marshal.list:5) */
extern void swfdec_marshal_VOID__UINT_UINT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

G_END_DECLS

#endif /* __swfdec_marshal_MARSHAL_H__ */

==> swfdec-0.5.3.tar.gz: swfdec-0.5.3/libswfdec/swfdec_marshal.h <==

#ifndef __swfdec_marshal_MARSHAL_H__
#define __swfdec_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:DOUBLE,DOUBLE,INT (./swfdec_marshal.list:1) */
extern void swfdec_marshal_BOOLEAN__DOUBLE_DOUBLE_INT (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);

/* BOOLEAN:UINT,UINT,BOOLEAN (./swfdec_marshal.list:2) */
extern void swfdec_marshal_BOOLEAN__UINT_UINT_BOOLEAN (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);

/* VOID:BOXED,POINTER,UINT (./swfdec_marshal.list:3) */
extern void swfdec_marshal_VOID__BOXED_POINTER_UINT (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

/* VOID:STRING,STRING (./swfdec_marshal.list:4) */
extern void swfdec_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* VOID:ULONG,UINT (./swfdec_marshal.list:5) */
extern void swfdec_marshal_VOID__ULONG_UINT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

G_END_DECLS

#endif /* __swfdec_marshal_MARSHAL_H__ */
